@@ -1,26 +1,10 @@
 /***************************************************************************
  *            stuff.c
- *
- *  Sun Apr  2 12:30:15 2006
+ *			Xwota 0.4
+ *  Sat Jul 15 10:31:59 2006
  *  Copyright  2006  Emanuele Madeo IZ0ETE
  *  Email <iz0ete@fabaris.it>
  ****************************************************************************/
-
-/*
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -33,13 +17,10 @@
 #include <ctype.h>
 #include <stdlib.h>
 #include <time.h>
-
-
-#include "callbacks.h"
-#include "interface.h"
 #include "support.h"
+#include "xwota_main_callback.h"
 #include "global.h"
-#include "net.h"
+#include "stuff.h"
 
 
 
@@ -47,15 +28,17 @@ int load_preferences()
 {
 FILE *fp,*sf;
 struct stat statdir;
-gchar *home_dir,*work_dir,*preferences_file, *stats_file;
+gchar *home_dir,*logs_dir,*preferences_file, *stats_file;
 gchar program_version_entry[100],call_entry[100],freq_entry[100],country_entry[100],state_entry[100],grid_entry[100],county_entry[100],latitude_entry[100],longitude_entry[100],comments_entry[100],server_wotadb_entry[100];
-gchar port_entry[10],upload_interval_entry[10],check_update_entry[10];
+gchar port_entry[10],upload_interval_entry[10],check_update_entry[10],participate_entry[10],read_from_rig_entry[10],autoanswer_entry[10],autoanswer_text_entry[100],save_private_messages_entry[10],sound_private_messages_entry[10];
 int i;
 
-home_dir = g_get_home_dir();
 
+home_dir = g_get_home_dir();
+//home_dir = g_strdup("/tmp");
 work_dir = g_strdup_printf("%s/.xwota",home_dir);
-	
+logs_dir = g_strdup_printf("%s/logs",work_dir);
+
 if (stat (work_dir, &statdir) == -1)
     {
       if (mkdir (work_dir, S_IRUSR | S_IWUSR | S_IXUSR) == -1){
@@ -63,6 +46,15 @@ if (stat (work_dir, &statdir) == -1)
 		  }
 
     }
+	
+if (stat (logs_dir, &statdir) == -1)
+    {
+      if (mkdir (logs_dir, S_IRUSR | S_IWUSR | S_IXUSR) == -1){
+	  //        printf("Creating ~/.%s directory.",logs_dir);
+		  }
+
+    }	
+	
 
 preferences_file = g_strdup_printf("%s/xwota.conf",work_dir);
 stats_file = g_strdup_printf("%s/stats",work_dir);
@@ -72,7 +64,7 @@ stats_file = g_strdup_printf("%s/stats",work_dir);
 	{
 	//printf("Creating %s file.\n",preferences_file);
 	
-		xwota_settings.program_version = g_strdup("0.2");
+		xwota_settings.program_version = g_strdup("0.4");
 		xwota_settings.call = g_strdup("NOCALL");
 		xwota_settings.freq = g_strdup("");
 		xwota_settings.country = g_strdup("");
@@ -85,7 +77,13 @@ stats_file = g_strdup_printf("%s/stats",work_dir);
 		xwota_settings.server_wotadb = g_strdup("server1.wotadb.org");
 		xwota_settings.port = g_strdup("1001");
 		xwota_settings.upload_interval = g_strdup("5");
-		xwota_settings.check_update = g_strdup("0");
+		xwota_settings.check_update = g_strdup("-1");
+		xwota_settings.participate = g_strdup("1");
+		xwota_settings.read_from_rig = g_strdup("0");
+		xwota_settings.autoanswer = g_strdup("0");
+		xwota_settings.autoanswer_text = g_strdup("Sorry, I'm away from computer.");
+		xwota_settings.save_private_messages = g_strdup("0");
+		xwota_settings.sound_private_messages = g_strdup("0");
 		
 				
 		if((fp=fopen(preferences_file,"w"))==NULL){
@@ -108,6 +106,15 @@ stats_file = g_strdup_printf("%s/stats",work_dir);
 		fprintf(fp,"%s\n",xwota_settings.port);
 		fprintf(fp,"%s\n",xwota_settings.upload_interval);
 		fprintf(fp,"%s\n",xwota_settings.check_update);
+		fprintf(fp,"%s\n",xwota_settings.participate);
+		fprintf(fp,"%s\n",xwota_settings.read_from_rig);
+		fprintf(fp,"%s\n",xwota_settings.autoanswer);
+		fprintf(fp,"%s\n",xwota_settings.autoanswer_text);
+		fprintf(fp,"%s\n",xwota_settings.save_private_messages);
+		fprintf(fp,"%s\n",xwota_settings.sound_private_messages);
+		
+		
+		
 				
 		fclose(fp);
 		return 1;
@@ -129,7 +136,7 @@ stats_file = g_strdup_printf("%s/stats",work_dir);
 	for(i=0;i<101;i++)longitude_entry[i] = '\0';
 	for(i=0;i<101;i++)comments_entry[i] = '\0';
 	for(i=0;i<101;i++)server_wotadb_entry[i] = '\0';
-				
+	for(i=0;i<101;i++)autoanswer_text_entry[i] = '\0';			
 						
 	fgets(program_version_entry,100,fp);
 	fgets(call_entry,100,fp);
@@ -145,6 +152,14 @@ stats_file = g_strdup_printf("%s/stats",work_dir);
 	fgets(port_entry,10,fp);
 	fgets(upload_interval_entry,10,fp);
 	fgets(check_update_entry,10,fp);
+	fgets(participate_entry,10,fp);
+	fgets(read_from_rig_entry,10,fp);
+	fgets(autoanswer_entry,10,fp);
+	fgets(autoanswer_text_entry,100,fp);
+	fgets(save_private_messages_entry,10,fp);
+	fgets(sound_private_messages_entry,10,fp);
+	
+	
 	
 	g_strdelimit(program_version_entry,"\n",'\0');
 	g_strdelimit(call_entry,"\n",'\0');
@@ -160,6 +175,14 @@ stats_file = g_strdup_printf("%s/stats",work_dir);
 	g_strdelimit(port_entry,"\n",'\0');
 	g_strdelimit(upload_interval_entry,"\n",'\0');
 	g_strdelimit(check_update_entry,"\n",'\0');
+	g_strdelimit(participate_entry,"\n",'\0');
+	g_strdelimit(read_from_rig_entry,"\n",'\0');
+	g_strdelimit(autoanswer_entry,"\n",'\0');
+	g_strdelimit(autoanswer_text_entry,"\n",'\0');
+	g_strdelimit(save_private_messages_entry,"\n",'\0');
+	g_strdelimit(sound_private_messages_entry,"\n",'\0');
+	
+	
 	
 	
 	
@@ -177,6 +200,12 @@ stats_file = g_strdup_printf("%s/stats",work_dir);
 		xwota_settings.port = g_strdup(port_entry);
 		xwota_settings.upload_interval = g_strdup(upload_interval_entry);
 		xwota_settings.check_update = g_strdup(check_update_entry);
+		xwota_settings.participate = g_strdup(participate_entry);
+		xwota_settings.read_from_rig = g_strdup(read_from_rig_entry);
+		xwota_settings.autoanswer = g_strdup(autoanswer_entry);
+		xwota_settings.autoanswer_text = g_strdup(autoanswer_text_entry);
+		xwota_settings.save_private_messages = g_strdup(save_private_messages_entry);
+		xwota_settings.sound_private_messages = g_strdup(sound_private_messages_entry);
 		
 		
 // Creo il file di stats_file
@@ -197,11 +226,16 @@ if(stat(stats_file,&statdir) == -1)
 }
 
 
+// SAVE PREFERENCES
+
 void save_preferences () {
 FILE *fp;	
 gchar *home_dir,*work_dir,*preferences_file;
 
+// DA TOGLIERE PRIMA DEL RILASCIO !!
+	
 home_dir = g_get_home_dir();
+//home_dir = g_strdup("/tmp");
 work_dir = g_strdup_printf("%s/.xwota",home_dir);
 preferences_file = g_strdup_printf("%s/xwota.conf",work_dir);
 
@@ -227,30 +261,56 @@ preferences_file = g_strdup_printf("%s/xwota.conf",work_dir);
 		fprintf(fp,"%s\n",xwota_settings.port);
 		fprintf(fp,"%s\n",xwota_settings.upload_interval);
 		fprintf(fp,"%s\n",xwota_settings.check_update);
-				
+		fprintf(fp,"%s\n",xwota_settings.participate);
+		fprintf(fp,"%s\n",xwota_settings.read_from_rig);
+		fprintf(fp,"%s\n",xwota_settings.autoanswer);	
+		fprintf(fp,"%s\n",xwota_settings.autoanswer_text);	
+		fprintf(fp,"%s\n",xwota_settings.save_private_messages);	
+		fprintf(fp,"%s\n",xwota_settings.sound_private_messages);	
 		fclose(fp);	
 	
 }
 
+// UPPERCASE
 
-void write_statusbar(char *message){
-
-gtk_statusbar_push(statusbar1,1,message);
+gchar *uppercase(gchar *upper) {
+	
+int upper_len,i;
+	upper_len=strlen(upper);
+	for(i=0;i<upper_len+1;i++) {
+		upper[i] = toupper(upper[i]);
+	}
+return upper;
 	
 }
 
-	void write_message_statusbar(char *message){
+// Main statusbar
+void write_main_statusbar(char *message){
+gtk_statusbar_push(left_main_statusbar,1,message);
+//gtk_statusbar_push(statusbar2,1,message);	
+}
 
-gtk_statusbar_push(message_statusbar,1,message);
+
+void write_message_statusbar(char *message){
+
+gtk_statusbar_push(left_private_messages_statusbar,1,message);
 	
 }
+
+// AUTOMATIC UPLOAD
 guint automatic_upload()
 {
 	
 	if (connection_status == 1) {
 //		printf("Upload info.\n");
+		if(strcmp(gtk_combo_box_get_active_text(GTK_COMBO_BOX(participate_combo)),"Yes") == 0) {			
 		on_update_button_clicked (NULL,NULL);
 		return TRUE;
+		}
+		else {
+//			printf("Not participating...\n");
+			return TRUE;
+		}
 	}
  else {
 //printf("Removing timeout.\n");
@@ -259,63 +319,6 @@ guint automatic_upload()
 	
 }
 
-guint check_freq ()
-{
-	gchar *get_frequency;
-	char frequency_entry[100];	
-	
-	if (connection_status == 1) {
-	get_frequency= gtk_entry_get_text(GTK_ENTRY(frequency));
-	strcpy(frequency_entry,get_frequency);
-	//printf("Freq check: %s - Old Freq: %s\n",get_frequency,old_freq);
-	
-	if(strcmp(get_frequency,old_freq) == 0) {
-		return TRUE;
-	}
-	else {
-		
-		automatic_upload();
-	}
-	
-}
-	
-else {	
-	return FALSE;
-}
-	return TRUE;
-}
-
-// COUNTRY LOOKUP
-gchar *country_lookup (gchar *country_code) {
-
-FILE *cf;
-gchar *country_file;
-gchar *code, *country;
-gchar country_entry[50];
-	
-//printf("Country code %s conversion.\n",country_code);
-country_file = g_strdup_printf("%s/%s/country.txt",PACKAGE_DATA_DIR,PACKAGE);
-//	printf("CF : %s\n",country_file);
-		if((cf=fopen(country_file,"r"))==NULL){
-		printf("Error opening country file !\n");
-			return country_code;
-		}	
-while(!feof(cf)) {
-	fgets(country_entry,100,cf);
-	code = strtok(country_entry," ");
-	country = strtok(NULL,"");
-
-//printf("%s %s\n",code,country);	
-	if(strcmp(code,country_code) == 0) {
-		return country;
-	}
-
-}
-country = g_strdup("UNKNOWN");
-fclose(cf);	
-return country;
-	
-}
 
 // DECODE MESSAGE
 
@@ -335,15 +338,15 @@ char *country_name;
 int status_digit,i;	
 	 
 	 strcpy(eor,"<EOR>"); 
-	// printf("Decode: %s\n",msg); 
+//	printf("Decode: %s\n",msg); 
 	//  printf("First char %c\n",msg[0]);
 	
 	  if(msg[0] == ':' )
 	  {
 	//  printf("Not implemented yet.\n");
 		  if (msg[1] == 'M') {
-			//  printf("Message received\n");
-			  decode_text_message(msg);
+			 //printf("Message received\n");
+			 decode_text_message(msg);
 			  
 		  		return -1;
 			  }
@@ -357,7 +360,7 @@ int status_digit,i;
 // se non c'è il fine record
 	  if ((p_eor = strstr(msg,eor)) == NULL)
 	  {
-		 printf("Incorrect message type\n");
+		// printf("Incorrect message type\n");
 	  
 		  return -1;
 	  }
@@ -431,7 +434,8 @@ sprintf(datetime,"%s %s",d_ate,t_ime);
 	
 	
 // Inserisco lo spot nella spot list
-spot_list = lookup_widget(GTK_WIDGET(spot_window),"spot_list");
+
+spot_list = lookup_widget(GTK_WIDGET(xwota_main),"spot_list");
 store = gtk_tree_view_get_model(spot_list);
 gtk_tree_store_append (GTK_TREE_STORE(store), &iter1, NULL); 
 gtk_tree_store_set(GTK_TREE_STORE(store),&iter1,DATETIME_COLUMN,datetime,CALL_COLUMN,call,FREQ_COLUMN,freq,COUNTRY_COLUMN,display_country,STATE_COLUMN,state,GRID_COLUMN,grid,
@@ -451,15 +455,87 @@ return 0;
 }
 
 
+// COUNTRY LOOKUP
+gchar *country_lookup (gchar *country_code) {
+
+FILE *cf;
+gchar *country_file;
+gchar *code, *country;
+gchar country_entry[50];
+	
+//printf("Country code %s conversion.\n",country_code);
+country_file = g_strdup_printf("%s/%s/country.txt",PACKAGE_DATA_DIR,PACKAGE);
+//	printf("CF : %s\n",country_file);
+		if((cf=fopen(country_file,"r"))==NULL){
+		printf("Error opening country file !\n");
+			return country_code;
+		}	
+while(!feof(cf)) {
+	fgets(country_entry,100,cf);
+	code = strtok(country_entry," ");
+	country = strtok(NULL,"");
+
+//printf("%s %s\n",code,country);	
+	if(strcmp(code,country_code) == 0) {
+		return country;
+	}
+
+}
+country = g_strdup("UNKNOWN");
+fclose(cf);	
+return country;
+	
+}
+
+// Check frequency changes and upload when needed.
+guint check_freq ()
+{
+	gchar *get_frequency;
+	char frequency_entry[100];	
+	
+	if (connection_status == 1) {
+		// jump check if not participating
+		if(strcmp(gtk_combo_box_get_active_text(GTK_COMBO_BOX(participate_combo)),"No") == 0) {			
+		return TRUE;
+		}
+	get_frequency= gtk_entry_get_text(GTK_ENTRY(frequency));
+	strcpy(frequency_entry,get_frequency);
+	//printf("Freq check: %s - Old Freq: %s\n",get_frequency,old_freq);
+	
+	if(strcmp(get_frequency,old_freq) == 0) {
+		freq_change_count = 0; // reset frequency change count
+		return TRUE;
+	}
+	else {
+		
+		if(freq_change_count == 2) { // ok, the frequency is stabilzed,upload granted.
+		automatic_upload();
+		freq_change_count = 0;
+		return TRUE;	
+		}
+	//printf("Frequency not stabilized.\n");	
+	freq_change_count++;
+	}
+	
+}
+	
+else {	
+	return FALSE;
+}
+	return TRUE;
+}
+
+
+
 int decode_text_message(gchar *msg)
 {
 	  GtkTreeIter iter;
 	  GtkTreeStore *store_message;
 	  GtkTreePath *path;
-	  GtkWidget *messages_list;
+	  GtkWidget *private_messages_list;
 	
 	gchar *from, *to, *text;	
-	char date_msg[30];
+	char date_msg[30],date_msg_log[12],time_log[6];
 	struct tm *utc;
 	time_t t;
 
@@ -467,6 +543,9 @@ t=time(NULL);
 utc = gmtime(&t);
 //printf("Time: %d-%d-%d %d:%d\n",(utc->tm_year)+1900,utc->tm_mon,utc->tm_mday,utc->tm_hour,utc->tm_min);
 sprintf(date_msg,"%d-%d-%d %d:%d",(utc->tm_year)+1900,utc->tm_mon,utc->tm_mday,utc->tm_hour,utc->tm_min);
+sprintf(date_msg_log,"%d-%d-%d",(utc->tm_year)+1900,utc->tm_mon,utc->tm_mday);
+sprintf(time_log,"%d:%d",utc->tm_hour,utc->tm_min);
+
 	//printf("Decoding text message %s\n",msg);	
 msg++;
 msg++;
@@ -478,18 +557,87 @@ msg++;
 	
 
 
-messages_list = lookup_widget(GTK_WIDGET(messages_window),"messages_list");
-store_message = gtk_tree_view_get_model(messages_list);
+private_messages_list = lookup_widget(GTK_WIDGET(private_messages_window),"private_messages_list");
+store_message = gtk_tree_view_get_model(private_messages_list);
 gtk_tree_store_append (GTK_TREE_STORE(store_message), &iter, NULL); 
 gtk_tree_store_set(GTK_TREE_STORE(store_message),&iter,DATETIME_MSG_COLUMN,date_msg,MSG_FROM_COLUMN,from,MSG_TO_COLUMN,to,MESSAGE_TEXT_COLUMN,text,-1);
 
  path = gtk_tree_model_get_path (GTK_TREE_MODEL (store_message), &iter);
- gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (messages_list), path,NULL, TRUE, 0.0, 1.0);
+ gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (private_messages_list), path,NULL, TRUE, 0.0, 1.0);
  gtk_tree_path_free (path);
 	
-gtk_widget_show(messages_window);
+gtk_widget_show(private_messages_window);
+
+if(strcmp(xwota_settings.sound_private_messages,"1") == 0) {	
+gdk_beep();
+}
+	
+	if(strcmp(xwota_settings.save_private_messages,"1") == 0) {
+//printf("Save message\n");
+private_messages_log(date_msg_log,time_log,from,to,text);	
+}	
+
+// Autoanswer
+if(strcmp(to,xwota_settings.call) == 0) {
+// mettere controllo qui per non allooppare
+  if(strcmp(gtk_combo_box_get_active_text(GTK_COMBO_BOX(autoanswer_combo)),"Yes") == 0) {			
+		;
+// riempio i campi e clikko send
+
+	GtkWidget* send_to = lookup_widget(GTK_WIDGET(private_messages_window),"send_to");
+	GtkWidget* private_message_text = lookup_widget(GTK_WIDGET(private_messages_window),"private_message_text");
+
+	gtk_entry_set_text(GTK_ENTRY(send_to),from);
+	gtk_entry_set_text(GTK_ENTRY(private_message_text),xwota_settings.autoanswer_text);	
+	on_send_private_message_button_clicked();
+	
+	}
+}	
+//----------------------
+
 	return 1;
 	}
+//-------- DECODE TEXT MESSAGE END -----------
+
+void private_messages_log(gchar *date_msg_log,gchar *time_log,gchar *from,gchar *to,gchar *text)
+{
+FILE *lf;
+struct stat statdir;
+char string_to_log[1024],*log_filename;
+
+//sprintf(log_filename,"%s",date_msg_log);
+sprintf(string_to_log,"%s %s - %s -> %s : %s",date_msg_log,time_log,from,to,text);
+
+//printf("Log: %s\n",string_to_log);
+
+log_filename = g_strdup_printf("%s/logs/%s",work_dir,date_msg_log);
+
+//printf("Log file: %s\n",log_filename);
+
+
+if(stat(log_filename,&statdir) == -1)
+	{
+//	printf("Creating %s file.\n",log_filename);
+	if((lf=fopen(log_filename,"w"))==NULL){
+		printf("Error opening message log file !\n");
+		}
+		else {
+		fprintf(lf,"%s\n",string_to_log);
+		fclose(lf);
+		}
+	}
+else {
+		if((lf=fopen(log_filename,"a"))==NULL){
+		printf("Error opening message log file !\n");
+		}
+		else {		
+		fprintf(lf,"%s\n",string_to_log);
+		fclose(lf);
+		}
+	}	
+}
+
+	
 // STATS
 int add_to_stats(gchar *call) {
 FILE *sf;
@@ -521,154 +669,13 @@ fclose(sf);
 	return 1;	
 }
 
-// CALL UPPERCASE
 
-gchar *uppercase(gchar *upper) {
-	
-int upper_len,i;
-	upper_len=strlen(upper);
-	for(i=0;i<upper_len+1;i++) {
-		upper[i] = toupper(upper[i]);
-	}
-return upper;
+void write_query_statusbar(char *message){
+
+gtk_statusbar_push(query_statusbar,1,message);
 	
 }
 
-
-
-
-
-
-
-// CREATE SPOTLIST
-
-GtkWidget *create_spot_list() {
-	
-	GtkWidget *spot_list;
-	GtkTreeStore *store;
-	GtkCellRenderer *renderer,*boldrenderer;
-	GtkTreeViewColumn *column;
-	
-	
-// Spot List
-
-store = gtk_tree_store_new(10,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,
-G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING);
-
-  spot_list = gtk_tree_view_new_with_model (GTK_TREE_MODEL(store));
-  g_object_unref (G_OBJECT (store));
- 
- 
-  renderer = gtk_cell_renderer_text_new ();
-  boldrenderer = gtk_cell_renderer_text_new ();
-   g_object_set (G_OBJECT (boldrenderer), "weight", "bold", NULL);
-// date - time
-  column = gtk_tree_view_column_new_with_attributes ("Date/Time", renderer,
-                                                      "text", DATETIME_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (spot_list), column);
-   
-// Call
-
-column = gtk_tree_view_column_new_with_attributes ("Call", boldrenderer,
-                                                      "text", CALL_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (spot_list), column);
- // Freq
-  column = gtk_tree_view_column_new_with_attributes ("Freq", renderer,
-                                                      "text", FREQ_COLUMN	,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (spot_list), column);
-  // Country
-  column = gtk_tree_view_column_new_with_attributes ("Country", renderer,
-                                                      "text", COUNTRY_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (spot_list), column);
-
-// State
-  column = gtk_tree_view_column_new_with_attributes ("State", renderer,
-                                                      "text", STATE_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (spot_list), column);
-// Grid  
-  column = gtk_tree_view_column_new_with_attributes ("Grid", renderer,
-                                                      "text", GRID_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (spot_list), column);
-// County  
-  column = gtk_tree_view_column_new_with_attributes ("County", renderer,
-                                                      "text", COUNTY_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (spot_list), column);
-// Lat - Long  
-  column = gtk_tree_view_column_new_with_attributes ("Lat/Long", renderer,
-                                                      "text", LATLONG_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (spot_list), column);
-//Status  
-  column = gtk_tree_view_column_new_with_attributes ("Status", renderer,
-                                                      "text", STATUS_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (spot_list), column);
-//Comment  
-  column = gtk_tree_view_column_new_with_attributes ("Comments", renderer,
-                                                      "text", COMMENTS_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (spot_list), column);
-  
-
-	return spot_list;
-	
-}
-
-
-GtkWidget *create_messages_list() {
-
-	GtkWidget *messages_list;
-	GtkTreeStore *store_message;
-	GtkCellRenderer *renderer,*boldrenderer;
-	GtkTreeViewColumn *column;
-	GObject *msg_selection;
-	
-	
-	
-store_message = gtk_tree_store_new(4,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING);
-messages_list = gtk_tree_view_new_with_model (GTK_TREE_MODEL(store_message));
- 
-	g_object_unref (G_OBJECT (store_message));
- 
- 
-  renderer = gtk_cell_renderer_text_new ();
-  boldrenderer = gtk_cell_renderer_text_new ();
-   g_object_set (G_OBJECT (boldrenderer), "weight", "bold", NULL);
-// date - time
-  column = gtk_tree_view_column_new_with_attributes ("Date/Time", renderer,
-                                                      "text", DATETIME_MSG_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (messages_list), column);
-	
-	column = gtk_tree_view_column_new_with_attributes ("From", boldrenderer,
-                                                      "text", MSG_FROM_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (messages_list), column);
-  
-  column = gtk_tree_view_column_new_with_attributes ("To", boldrenderer,
-                                                      "text", MSG_TO_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (messages_list), column);
-  
-  column = gtk_tree_view_column_new_with_attributes ("Message", renderer,
-                                                      "text", MESSAGE_TEXT_COLUMN,
-                                                      NULL);
-  gtk_tree_view_append_column (GTK_TREE_VIEW (messages_list), column);
-	
-	msg_selection = gtk_tree_view_get_selection(messages_list);
-	g_signal_connect (msg_selection, "changed", G_CALLBACK (message_selected), NULL);
-
-return messages_list;	
-}
-
-
 void write_manual (GtkWidget *manual_text) {
 
 FILE *mf;
